attribute vec4 a_position;
attribute vec4 a_position_blend;

attribute vec3 a_normal;
attribute vec3 a_normal_blend;

attribute vec2 a_texcoord_0;

varying vec2 v_texcoord_0;
varying vec3 v_lighting;

uniform mat4 u_mtx_modelviewproj;
uniform float u_float_blendamount;

uniform float u_float_angle;

uniform vec4 u_color_1; // ambient color
uniform vec4 u_color_0; // light color
uniform vec3 u_vec3_translation; // light vector, pre-oriented

void main()
{
	// first calculate the blended position and normals
	vec4 posBlended = mix( a_position, a_position_blend, u_float_blendamount );
	vec3 normBlended = mix( a_normal, a_normal_blend, u_float_blendamount );
	
	// now, based on how far from the head we are (0 on y, with the body moving towards positive y)
	// we'll rotate those positions around the Z axis, so the fish's body can
	// look like it's bending appropriately as it turns.  u_float_angle is considered
	// relative to the head's angle, as a result
	
	float angle = u_float_angle * ( a_position.y * 0.10 ); // so the angle gets greater with distance
	float r = radians(angle);

	vec4 new_position;
	float rCos = cos(r);
	float rSin = sin(r);
	
	// shorten Y the higher the angle gets, to compensate for the lateral
	// travel and avoid being so stretchy at high angles
	//float adjustedY = posBlended.y - ( posBlended.y * ( abs(u_float_angle)/360.0 ) );
	
	new_position.w = posBlended.w;  
	new_position.x = posBlended.x * rCos - posBlended.y * rSin;
	new_position.y = posBlended.x * rSin + posBlended.y * rCos;
	new_position.z = posBlended.z;
	
	posBlended = new_position;
	
	gl_Position = u_mtx_modelviewproj * posBlended;
	v_texcoord_0 = a_texcoord_0;
	
	vec3 lighting = dot( u_vec3_translation, normBlended ) * u_color_0.rgb;
	v_lighting = max( u_color_1.rgb, lighting );
}
